usage: create_cli_help.py restore [-h] [-x] [-N EXCLUDE_SCHEMA] file

### positional arguments:
- `file`: The backup file

### options:
- `-h, --help`: show this help message and exit
- `-x`: ignore pg_restore errors
- `-N EXCLUDE_SCHEMA, --exclude-schema EXCLUDE_SCHEMA`
- `Schema to be ignored.`
